@@ -123,7 +123,7 @@ class Config(Model):
         default="copy",
     )  # type: StringType
     dask_enabled = BooleanType(default=False, required=True)  # type: BooleanType
-    dask_partitions = IntType(
+    dask_workers = IntType(
         default=8, required=True, validators=[lambda x: vd.is_gt(x, 0)]
     )  # type: IntType
 
@@ -140,7 +140,7 @@ class Config(Model):
     exporters = ModelType(ExportersConfig, required=False, default={})  # type: ModelType
 
     class WebhookConfig(Model):
-        url = URLType(required=True)  # type: URLType
+        url = URLType(required=True, fqdn=False)  # type: URLType
         method = StringType(required=True, validators=[vd.is_http_method])  # type: StringType
         headers = DictType(StringType, required=False)  # type: DictType
         data = DictType(BaseType, required=False, serialize_when_none=False)  # type: DictType
