@@ -174,8 +174,7 @@ class Database:
             raise NameError(msg)
 
         # setup logger
-        logpath = Path(hb_root, 'logs', 'progress', 'hidebound-progress.log')
-        self._logger = ProgressLogger(__name__, logpath)
+        self._logger = ProgressLogger(__name__)
 
         # validate spec classes
         bad_specs = list(filter(
@@ -217,7 +216,7 @@ class Database:
         # needed for testing
         self.__exporter_lut = None
 
-        self._logger.info('Database initialized')
+        self._logger.info('Database initialized', step=1, total=1)
 
     def create(self):
         # type: () -> "Database"
@@ -516,7 +515,7 @@ class Database:
                 self.__exporter_lut[key] = exporter
 
         list(self.call_webhooks())
-        self._logger.info('export: complete')
+        self._logger.info('export: complete', step=i + 1, total=total)
         return self
 
     def search(self, query, group_by_asset=False):
